@@ -8,30 +8,16 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#pragma once
+
 //view data structure
-#ifndef VIEWPORT_H
-#define VIEWPORT_H
-#define bool int
 #include "smyrnadefs.h"
 #include <gtk/gtk.h>
 #include <xdot/xdot.h>
 #include <cgraph/cgraph.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
     void init_viewport(ViewInfo * view);
     void set_viewport_settings_from_template(ViewInfo * view, Agraph_t *);
-#if 0
-    void clear_viewport(ViewInfo * view);
-    colorschemaset *create_color_theme(int themeid);
-    md5_byte_t *get_md5_key(Agraph_t * graph);
-    void fill_key(md5_byte_t * b, md5_byte_t * data);
-    void movenode(void *n, float dx, float dy);
-    void please_dont_wait(void);
-    void please_wait(void);
-#endif
     void switch_graph(int);
     void refreshViewport(int doClear);
     int add_graph_to_viewport_from_file(char *fileName);
@@ -51,11 +37,5 @@ extern "C" {
 
 
     /* helper functions */
-    extern int setGdkColor(GdkColor * c, char *color);
     extern char *get_attribute_value(char *attr, ViewInfo * view,
 				     Agraph_t * g);
-
-#ifdef __cplusplus
-}				/* end extern "C" */
-#endif
-#endif
