@@ -85,22 +85,23 @@
 #define N_NEW(n,t)   calloc((n),sizeof(t))
 #define RALLOC(size,ptr,type) realloc(ptr,(size)*sizeof(type))
 
-typedef unsigned short ushort;
-
 static gmlgraph* G;
 static gmlnode* N;
 static gmledge* E;
 static Dt_t* L;
 static Dt_t** liststk;
-static int liststk_sz;
-static int liststk_cnt;
+static size_t liststk_sz;
+static size_t liststk_cnt;
 
 static void free_attr (Dt_t*d, gmlattr* p, Dtdisc_t* ds); /* forward decl */
-static char* sortToStr (int sort);    /* forward decl */
+static char *sortToStr(unsigned short sort);
 
 static void
 free_node (Dt_t*d, gmlnode* p, Dtdisc_t* ds)
 {
+    (void)d;
+    (void)ds;
+
     if (!p) return;
     if (p->attrlist) dtclose (p->attrlist);
     free (p);
@@ -109,6 +110,9 @@ free_node (Dt_t*d, gmlnode* p, Dtdisc_t* ds)
 static void
 free_edge (Dt_t*d, gmledge* p, Dtdisc_t* ds)
 {
+    (void)d;
+    (void)ds;
+
     if (!p) return;
     if (p->attrlist) dtclose (p->attrlist);
     free (p);
@@ -117,6 +121,9 @@ free_edge (Dt_t*d, gmledge* p, Dtdisc_t* ds)
 static void
 free_graph (Dt_t*d, gmlgraph* p, Dtdisc_t* ds)
 {
+    (void)d;
+    (void)ds;
+
     if (!p) return;
     if (p->nodelist)
 	dtclose (p->nodelist);
@@ -188,10 +195,8 @@ initstk (void)
 static void
 cleanup (void)
 {
-    int i;
-
     if (liststk) {
-	for (i = 0; i < liststk_cnt; i++)
+	for (size_t i = 0; i < liststk_cnt; i++)
 	    dtclose (liststk[i]);
 	free (liststk);
 	liststk = NULL;
@@ -285,9 +290,8 @@ mkEdge (void)
     return ep;
 }
 
-static gmlattr*
-mkAttr (char* name, int sort, int kind, char* str, Dt_t* list)
-{
+static gmlattr *mkAttr(char* name, unsigned short sort, unsigned short kind,
+                       char* str,  Dt_t* list) {
     gmlattr* gp = NEW(gmlattr);
 
     assert (name || sort);
@@ -305,7 +309,7 @@ mkAttr (char* name, int sort, int kind, char* str, Dt_t* list)
 	}
 	gp->u.lp = list;
     }
-/* fprintf (stderr, "[%x] %d %d \"%s\" \"%s\" \n", gp, sort, kind, (name?name:""),  (str?str:"")); */
+/* fprintf (stderr, "[%x] %hu %hu \"%s\" \"%s\" \n", gp, sort, kind, (name?name:""),  (str?str:"")); */
     return gp;
 }
 
@@ -334,7 +338,7 @@ setDir (char* d)
 }
 
 
-#line 338 "gmlparse.c" /* yacc.c:339  */
+#line 342 "gmlparse.c" /* yacc.c:339  */
 
 # ifndef YY_NULLPTR
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -450,7 +454,7 @@ extern int gmldebug;
 
 union GMLSTYPE
 {
-#line 281 "../../cmd/tools/gmlparse.y" /* yacc.c:355  */
+#line 285 "../../cmd/tools/gmlparse.y" /* yacc.c:355  */
 
     int i;
     char *str;
@@ -459,7 +463,7 @@ union GMLSTYPE
     gmlattr* ap;
     Dt_t*    list;
 
-#line 463 "gmlparse.c" /* yacc.c:355  */
+#line 467 "gmlparse.c" /* yacc.c:355  */
 };
 
 typedef union GMLSTYPE GMLSTYPE;
@@ -476,7 +480,7 @@ int gmlparse (void);
 
 /* Copy the second part of user declarations.  */
 
-#line 480 "gmlparse.c" /* yacc.c:358  */
+#line 484 "gmlparse.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -776,13 +780,13 @@ static const yytype_uint8 yytranslate[] =
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   304,   304,   305,   306,   309,   312,   315,   316,   319,
-     320,   323,   324,   325,   326,   333,   334,   337,   337,   340,
-     341,   344,   345,   348,   348,   351,   352,   355,   356,   357,
-     358,   361,   361,   364,   365,   368,   369,   372,   373,   374,
-     375,   376,   377,   378,   379,   380,   381,   382,   383,   384,
-     385,   386,   387,   388,   389,   390,   391,   392,   393,   394,
-     395,   396,   397
+       0,   308,   308,   309,   310,   313,   316,   319,   320,   323,
+     324,   327,   328,   329,   330,   337,   338,   341,   341,   344,
+     345,   348,   349,   352,   352,   355,   356,   359,   360,   361,
+     362,   365,   365,   368,   369,   372,   373,   376,   377,   378,
+     379,   380,   381,   382,   383,   384,   385,   386,   387,   388,
+     389,   390,   391,   392,   393,   394,   395,   396,   397,   398,
+     399,   400,   401
 };
 #endif
 
@@ -1645,37 +1649,37 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 304 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 308 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     {gmllexeof(); if (G->parent) popG(); }
-#line 1651 "gmlparse.c" /* yacc.c:1646  */
+#line 1655 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 3:
-#line 305 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 309 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { cleanup(); YYABORT; }
-#line 1657 "gmlparse.c" /* yacc.c:1646  */
+#line 1661 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 5:
-#line 309 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 313 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { pushG(); }
-#line 1663 "gmlparse.c" /* yacc.c:1646  */
+#line 1667 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 11:
-#line 323 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 327 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { dtinsert (G->nodelist, (yyvsp[0].np)); }
-#line 1669 "gmlparse.c" /* yacc.c:1646  */
+#line 1673 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 12:
-#line 324 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 328 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { dtinsert (G->edgelist, (yyvsp[0].ep)); }
-#line 1675 "gmlparse.c" /* yacc.c:1646  */
+#line 1679 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 14:
-#line 326 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 330 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { 
 		if (setDir((yyvsp[0].str))) { 
 		    yyerror("mixed directed and undirected graphs"); 
@@ -1683,263 +1687,263 @@ yyreduce:
 		    YYABORT;
 		}
 	  }
-#line 1687 "gmlparse.c" /* yacc.c:1646  */
+#line 1691 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 15:
-#line 333 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 337 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { dtinsert (G->attrlist, mkAttr (strdup("id"), 0, INTEGER, (yyvsp[0].str), 0)); }
-#line 1693 "gmlparse.c" /* yacc.c:1646  */
+#line 1697 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 16:
-#line 334 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 338 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { dtinsert (G->attrlist, (yyvsp[0].ap)); }
-#line 1699 "gmlparse.c" /* yacc.c:1646  */
+#line 1703 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 17:
-#line 337 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 341 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { N = mkNode(); }
-#line 1705 "gmlparse.c" /* yacc.c:1646  */
+#line 1709 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 18:
-#line 337 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 341 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { (yyval.np) = N; N = NULL; }
-#line 1711 "gmlparse.c" /* yacc.c:1646  */
+#line 1715 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 21:
-#line 344 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 348 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { N->id = (yyvsp[0].str); }
-#line 1717 "gmlparse.c" /* yacc.c:1646  */
+#line 1721 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 22:
-#line 345 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 349 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { dtinsert (N->attrlist, (yyvsp[0].ap)); }
-#line 1723 "gmlparse.c" /* yacc.c:1646  */
+#line 1727 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 23:
-#line 348 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 352 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { E = mkEdge(); }
-#line 1729 "gmlparse.c" /* yacc.c:1646  */
+#line 1733 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 24:
-#line 348 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 352 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { (yyval.ep) = E; E = NULL; }
-#line 1735 "gmlparse.c" /* yacc.c:1646  */
+#line 1739 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 27:
-#line 355 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 359 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { E->source = (yyvsp[0].str); }
-#line 1741 "gmlparse.c" /* yacc.c:1646  */
+#line 1745 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 28:
-#line 356 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 360 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { E->target = (yyvsp[0].str); }
-#line 1747 "gmlparse.c" /* yacc.c:1646  */
+#line 1751 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 29:
-#line 357 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 361 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { dtinsert (E->attrlist, mkAttr (strdup("id"), 0, INTEGER, (yyvsp[0].str), 0)); }
-#line 1753 "gmlparse.c" /* yacc.c:1646  */
+#line 1757 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 30:
-#line 358 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 362 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { dtinsert (E->attrlist, (yyvsp[0].ap)); }
-#line 1759 "gmlparse.c" /* yacc.c:1646  */
+#line 1763 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 31:
-#line 361 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 365 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     {pushAlist(); }
-#line 1765 "gmlparse.c" /* yacc.c:1646  */
+#line 1769 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 32:
-#line 361 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 365 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { (yyval.list) = popAlist(); }
-#line 1771 "gmlparse.c" /* yacc.c:1646  */
+#line 1775 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 35:
-#line 368 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 372 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { dtinsert (L, (yyvsp[0].ap)); }
-#line 1777 "gmlparse.c" /* yacc.c:1646  */
+#line 1781 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 36:
-#line 369 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 373 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { dtinsert (L, (yyvsp[0].ap)); }
-#line 1783 "gmlparse.c" /* yacc.c:1646  */
+#line 1787 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 37:
-#line 372 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 376 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { (yyval.ap) = mkAttr ((yyvsp[-1].str), 0, INTEGER, (yyvsp[0].str), 0); }
-#line 1789 "gmlparse.c" /* yacc.c:1646  */
+#line 1793 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 38:
-#line 373 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 377 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { (yyval.ap) = mkAttr ((yyvsp[-1].str), 0, REAL, (yyvsp[0].str), 0); }
-#line 1795 "gmlparse.c" /* yacc.c:1646  */
+#line 1799 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 39:
-#line 374 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 378 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { (yyval.ap) = mkAttr ((yyvsp[-1].str), 0, STRING, (yyvsp[0].str), 0); }
-#line 1801 "gmlparse.c" /* yacc.c:1646  */
+#line 1805 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 40:
-#line 375 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 379 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { (yyval.ap) = mkAttr ((yyvsp[-1].str), 0, LIST, 0, (yyvsp[0].list)); }
-#line 1807 "gmlparse.c" /* yacc.c:1646  */
+#line 1811 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 41:
-#line 376 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 380 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { (yyval.ap) = mkAttr (0, XVAL, REAL, (yyvsp[0].str), 0); }
-#line 1813 "gmlparse.c" /* yacc.c:1646  */
+#line 1817 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 42:
-#line 377 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 381 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { (yyval.ap) = mkAttr (0, XVAL, REAL, (yyvsp[0].str), 0); }
-#line 1819 "gmlparse.c" /* yacc.c:1646  */
+#line 1823 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 43:
-#line 378 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 382 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { (yyval.ap) = mkAttr (0, YVAL, REAL, (yyvsp[0].str), 0); }
-#line 1825 "gmlparse.c" /* yacc.c:1646  */
+#line 1829 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 44:
-#line 379 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 383 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { (yyval.ap) = mkAttr (0, WVAL, REAL, (yyvsp[0].str), 0); }
-#line 1831 "gmlparse.c" /* yacc.c:1646  */
+#line 1835 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 45:
-#line 380 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 384 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { (yyval.ap) = mkAttr (0, HVAL, REAL, (yyvsp[0].str), 0); }
-#line 1837 "gmlparse.c" /* yacc.c:1646  */
+#line 1841 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 46:
-#line 381 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 385 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { (yyval.ap) = mkAttr (0, LABEL, STRING, (yyvsp[0].str), 0); }
-#line 1843 "gmlparse.c" /* yacc.c:1646  */
+#line 1847 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 47:
-#line 382 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 386 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { (yyval.ap) = mkAttr (0, GRAPHICS, LIST, 0, (yyvsp[0].list)); }
-#line 1849 "gmlparse.c" /* yacc.c:1646  */
+#line 1853 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 48:
-#line 383 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 387 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { (yyval.ap) = mkAttr (0, LABELGRAPHICS, LIST, 0, (yyvsp[0].list)); }
-#line 1855 "gmlparse.c" /* yacc.c:1646  */
+#line 1859 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 49:
-#line 384 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 388 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { (yyval.ap) = mkAttr (0, TYPE, STRING, (yyvsp[0].str), 0); }
-#line 1861 "gmlparse.c" /* yacc.c:1646  */
+#line 1865 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 50:
-#line 385 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 389 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { (yyval.ap) = mkAttr (0, FILL, STRING, (yyvsp[0].str), 0); }
-#line 1867 "gmlparse.c" /* yacc.c:1646  */
+#line 1871 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 51:
-#line 386 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 390 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { (yyval.ap) = mkAttr (0, OUTLINE, STRING, (yyvsp[0].str), 0); }
-#line 1873 "gmlparse.c" /* yacc.c:1646  */
+#line 1877 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 52:
-#line 387 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 391 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { (yyval.ap) = mkAttr (0, OUTLINESTYLE, STRING, (yyvsp[0].str), 0); }
-#line 1879 "gmlparse.c" /* yacc.c:1646  */
+#line 1883 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 53:
-#line 388 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 392 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { (yyval.ap) = mkAttr (0, OUTLINEWIDTH, INTEGER, (yyvsp[0].str), 0); }
-#line 1885 "gmlparse.c" /* yacc.c:1646  */
+#line 1889 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 54:
-#line 389 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 393 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { (yyval.ap) = mkAttr (0, WIDTH, REAL, (yyvsp[0].str), 0); }
-#line 1891 "gmlparse.c" /* yacc.c:1646  */
+#line 1895 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 55:
-#line 390 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 394 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { (yyval.ap) = mkAttr (0, STYLE, STRING, (yyvsp[0].str), 0); }
-#line 1897 "gmlparse.c" /* yacc.c:1646  */
+#line 1901 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 56:
-#line 391 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 395 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { (yyval.ap) = mkAttr (0, STYLE, LIST, 0, (yyvsp[0].list)); }
-#line 1903 "gmlparse.c" /* yacc.c:1646  */
+#line 1907 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 57:
-#line 392 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 396 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { (yyval.ap) = mkAttr (0, LINE, LIST, 0, (yyvsp[0].list)); }
-#line 1909 "gmlparse.c" /* yacc.c:1646  */
+#line 1913 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 58:
-#line 393 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 397 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { (yyval.ap) = mkAttr (0, POINT, LIST, 0, (yyvsp[0].list)); }
-#line 1915 "gmlparse.c" /* yacc.c:1646  */
+#line 1919 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 59:
-#line 394 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 398 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { (yyval.ap) = mkAttr (0, TEXT, STRING, (yyvsp[0].str), 0); }
-#line 1921 "gmlparse.c" /* yacc.c:1646  */
+#line 1925 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 60:
-#line 395 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 399 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { (yyval.ap) = mkAttr (0, FONTNAME, STRING, (yyvsp[0].str), 0); }
-#line 1927 "gmlparse.c" /* yacc.c:1646  */
+#line 1931 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 61:
-#line 396 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 400 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { (yyval.ap) = mkAttr (0, FONTNAME, INTEGER, (yyvsp[0].str), 0); }
-#line 1933 "gmlparse.c" /* yacc.c:1646  */
+#line 1937 "gmlparse.c" /* yacc.c:1646  */
     break;
 
   case 62:
-#line 397 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
+#line 401 "../../cmd/tools/gmlparse.y" /* yacc.c:1646  */
     { (yyval.ap) = mkAttr (0, COLOR, STRING, (yyvsp[0].str), 0); }
-#line 1939 "gmlparse.c" /* yacc.c:1646  */
+#line 1943 "gmlparse.c" /* yacc.c:1646  */
     break;
 
 
-#line 1943 "gmlparse.c" /* yacc.c:1646  */
+#line 1947 "gmlparse.c" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2167,14 +2171,17 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 400 "../../cmd/tools/gmlparse.y" /* yacc.c:1906  */
+#line 404 "../../cmd/tools/gmlparse.y" /* yacc.c:1906  */
 
 
 static void
 free_attr (Dt_t*d, gmlattr* p, Dtdisc_t* ds)
 {
+    (void)d;
+    (void)ds;
+
     if (!p) return;
-    if ((p->kind == LIST) && p->u.lp)
+    if (p->kind == LIST && p->u.lp)
 	dtclose (p->u.lp);
     else
 	free (p->u.value);
@@ -2228,9 +2235,7 @@ unknown (Agobj_t* obj, gmlattr* ap, agxbuf* xb)
     agsafeset (obj, ap->name, str, "");
 }
 
-static void
-addNodeLabelGraphics (Agnode_t* np, Dt_t* alist, agxbuf* xb, agxbuf* unk)
-{
+static void addNodeLabelGraphics(Agnode_t* np, Dt_t* alist, agxbuf* unk) {
     gmlattr* ap;
     int cnt = 0;
 
@@ -2357,10 +2362,10 @@ addNodeGraphics (Agnode_t* np, Dt_t* alist, agxbuf* xb, agxbuf* unk)
 	else if (ap->sort == OUTLINE) {
 	    agsafeset (np, "pencolor", ap->u.value, "");
 	}
-	else if ((ap->sort == WIDTH) || (ap->sort == OUTLINEWIDTH )) {
+	else if (ap->sort == WIDTH || ap->sort == OUTLINEWIDTH) {
 	    agsafeset (np, "penwidth", ap->u.value, "");
 	}
-	else if ((ap->sort == STYLE) || (ap->sort == OUTLINESTYLE )) {
+	else if (ap->sort == STYLE || ap->sort == OUTLINESTYLE) {
 	    agsafeset (np, "style", ap->u.value, "");
 	}
 	else {
@@ -2481,13 +2486,13 @@ addAttrs (Agobj_t* obj, Dt_t* alist, agxbuf* xb, agxbuf* unk)
 	}
 	else if (ap->sort == LABELGRAPHICS) {
 	    if (AGTYPE(obj) == AGNODE)
-		addNodeLabelGraphics ((Agnode_t*)obj, ap->u.lp, xb, unk);
+		addNodeLabelGraphics ((Agnode_t*)obj, ap->u.lp, unk);
 	    else if (AGTYPE(obj) == AGEDGE)
 		addEdgeLabelGraphics ((Agedge_t*)obj, ap->u.lp, xb, unk);
 	    else
 		unknown (obj, ap, xb);
 	}
-	else if ((ap->sort == LABEL) && (AGTYPE(obj) != AGRAPH)) {
+	else if (ap->sort == LABEL && AGTYPE(obj) != AGRAPH) {
 	    agsafeset (obj, "name", ap->u.value, "");
 	}
 	else
@@ -2495,9 +2500,8 @@ addAttrs (Agobj_t* obj, Dt_t* alist, agxbuf* xb, agxbuf* unk)
     }
 }
 
-static Agraph_t*
-mkGraph (gmlgraph* G, Agraph_t* parent, char* name, agxbuf* xb, agxbuf* unk)
-{
+static Agraph_t *mkGraph(gmlgraph *graph, Agraph_t *parent, char *name,
+                         agxbuf *xb, agxbuf *unk) {
     Agraph_t* g;
     Agnode_t* n;
     Agnode_t* h;
@@ -2509,7 +2513,7 @@ mkGraph (gmlgraph* G, Agraph_t* parent, char* name, agxbuf* xb, agxbuf* unk)
     if (parent) {
 	g = agsubg (parent, NULL, 1);
     }
-    else if (G->directed >= 1)
+    else if (graph->directed >= 1)
 	g = agopen (name, Agdirected, 0);
     else
 	g = agopen (name, Agundirected, 0);
@@ -2517,7 +2521,7 @@ mkGraph (gmlgraph* G, Agraph_t* parent, char* name, agxbuf* xb, agxbuf* unk)
     if (!parent && L) {
 	addAttrs ((Agobj_t*)g, L, xb, unk);
     } 
-    for (np = dtfirst(G->nodelist); np; np = dtnext (G->nodelist, np)) {
+    for (np = dtfirst(graph->nodelist); np; np = dtnext(graph->nodelist, np)) {
 	if (!np->id) {
 	   fprintf (stderr, "node without an id attribute"); 
 	   exit (1);
@@ -2526,7 +2530,7 @@ mkGraph (gmlgraph* G, Agraph_t* parent, char* name, agxbuf* xb, agxbuf* unk)
 	addAttrs ((Agobj_t*)n, np->attrlist, xb, unk);
     }
 
-    for (ep = dtfirst(G->edgelist); ep; ep = dtnext (G->edgelist, ep)) {
+    for (ep = dtfirst(graph->edgelist); ep; ep = dtnext(graph->edgelist, ep)) {
 	if (!ep->source) {
 	   fprintf (stderr, "edge without an source attribute"); 
 	   exit (1);
@@ -2540,11 +2544,11 @@ mkGraph (gmlgraph* G, Agraph_t* parent, char* name, agxbuf* xb, agxbuf* unk)
 	e = agedge (g, n, h, NULL, 1);
 	addAttrs ((Agobj_t*)e, ep->attrlist, xb, unk);
     }
-    for (gp = dtfirst(G->graphlist); gp; gp = dtnext (G->graphlist, gp)) {
+    for (gp = dtfirst(graph->graphlist); gp; gp = dtnext(graph->graphlist, gp)) {
 	mkGraph (gp, g, NULL, xb, unk);
     }
 
-    addAttrs ((Agobj_t*)g, G->attrlist, xb, unk);
+    addAttrs ((Agobj_t*)g, graph->attrlist, xb, unk);
 
     return g;
 }
@@ -2585,9 +2589,7 @@ gml_to_gv (char* name, FILE* fp, int cnt, int* errors)
     return g;
 }
 
-static char*
-sortToStr (int sort)
-{
+static char *sortToStr(unsigned short sort) {
     char* s;
 
     switch (sort) {
@@ -2665,18 +2667,3 @@ sortToStr (int sort)
 
     return s;
 }
-
-#if 0
-int gmllex ()
-{
-    int tok = _gmllex();
-    char* s = sortToStr (tok);
-
-    if (s)
-        fprintf (stderr, "token = %s\n", s);
-    else
-        fprintf (stderr, "token = <%d>\n", tok);
-    return tok;
-}
-#endif
-
