@@ -77,12 +77,9 @@
 #include <stdbool.h>
 #include <stdio.h>
 #include <cghdr.h>
+#include <cgraph/unreachable.h>
 #include <stddef.h>
-extern void aagerror(char *);
-
-#ifdef _WIN32
-#define gettxt(a,b)	(b)
-#endif
+extern void aagerror(const char*);
 
 static char Key[] = "key";
 static int SubgraphDepth = 0;
@@ -141,7 +138,7 @@ static	Agdisc_t	*Disc;		/* discipline passed to agread or agconcat */
 static gstack_t *S;
 
 
-#line 145 "grammar.c" /* yacc.c:339  */
+#line 142 "grammar.c" /* yacc.c:339  */
 
 # ifndef YY_NULLPTR
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -215,13 +212,13 @@ extern int aagdebug;
 
 union AAGSTYPE
 {
-#line 89 "../../lib/cgraph/grammar.y" /* yacc.c:355  */
+#line 86 "../../lib/cgraph/grammar.y" /* yacc.c:355  */
 
 			int				i;
 			char			*str;
 			struct Agnode_s	*n;
 
-#line 225 "grammar.c" /* yacc.c:355  */
+#line 222 "grammar.c" /* yacc.c:355  */
 };
 
 typedef union AAGSTYPE AAGSTYPE;
@@ -238,7 +235,7 @@ int aagparse (void);
 
 /* Copy the second part of user declarations.  */
 
-#line 242 "grammar.c" /* yacc.c:358  */
+#line 239 "grammar.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -536,13 +533,13 @@ static const yytype_uint8 yytranslate[] =
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,   106,   106,   107,   108,   111,   113,   116,   116,   118,
-     118,   120,   120,   122,   122,   124,   124,   126,   126,   128,
-     129,   132,   136,   136,   138,   138,   138,   139,   143,   143,
-     145,   146,   147,   150,   151,   154,   155,   156,   159,   160,
-     163,   163,   165,   167,   168,   170,   173,   173,   175,   178,
-     181,   184,   184,   187,   188,   189,   192,   192,   192,   194,
-     195,   198,   199
+       0,   103,   103,   104,   105,   108,   110,   113,   113,   115,
+     115,   117,   117,   119,   119,   121,   121,   123,   123,   125,
+     126,   129,   133,   133,   135,   135,   135,   136,   140,   140,
+     142,   143,   144,   147,   148,   151,   152,   153,   156,   157,
+     160,   160,   162,   164,   165,   167,   170,   170,   172,   175,
+     178,   181,   181,   184,   185,   186,   189,   189,   189,   191,
+     192,   195,   196
 };
 #endif
 
@@ -1367,217 +1364,217 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 106 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 103 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {freestack(); endgraph();}
-#line 1373 "grammar.c" /* yacc.c:1646  */
+#line 1370 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 3:
-#line 107 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 104 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {if (G) {freestack(); endgraph(); agclose(G); G = Ag_G_global = NULL;}}
-#line 1379 "grammar.c" /* yacc.c:1646  */
+#line 1376 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 6:
-#line 113 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 110 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {startgraph((yyvsp[0].str),(yyvsp[-1].i) != 0,(yyvsp[-2].i) != 0);}
-#line 1385 "grammar.c" /* yacc.c:1646  */
+#line 1382 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 7:
-#line 116 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 113 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.str)=(yyvsp[0].str);}
-#line 1391 "grammar.c" /* yacc.c:1646  */
+#line 1388 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 8:
-#line 116 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 113 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.str)=0;}
-#line 1397 "grammar.c" /* yacc.c:1646  */
+#line 1394 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 9:
-#line 118 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 115 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.i)=1;}
-#line 1403 "grammar.c" /* yacc.c:1646  */
+#line 1400 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 10:
-#line 118 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 115 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.i)=0;}
-#line 1409 "grammar.c" /* yacc.c:1646  */
+#line 1406 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 11:
-#line 120 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 117 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.i) = 0;}
-#line 1415 "grammar.c" /* yacc.c:1646  */
+#line 1412 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 12:
-#line 120 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 117 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.i) = 1;}
-#line 1421 "grammar.c" /* yacc.c:1646  */
+#line 1418 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 21:
-#line 133 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 130 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {if ((yyvsp[-1].i)) endedge(); else endnode();}
-#line 1427 "grammar.c" /* yacc.c:1646  */
+#line 1424 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 24:
-#line 138 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 135 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {getedgeitems();}
-#line 1433 "grammar.c" /* yacc.c:1646  */
+#line 1430 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 25:
-#line 138 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 135 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {getedgeitems();}
-#line 1439 "grammar.c" /* yacc.c:1646  */
+#line 1436 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 26:
-#line 138 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 135 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.i) = 1;}
-#line 1445 "grammar.c" /* yacc.c:1646  */
+#line 1442 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 27:
-#line 139 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 136 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.i) = 0;}
-#line 1451 "grammar.c" /* yacc.c:1646  */
+#line 1448 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 30:
-#line 145 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 142 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {appendnode((yyvsp[0].str),NULL,NULL);}
-#line 1457 "grammar.c" /* yacc.c:1646  */
+#line 1454 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 31:
-#line 146 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 143 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {appendnode((yyvsp[-2].str),(yyvsp[0].str),NULL);}
-#line 1463 "grammar.c" /* yacc.c:1646  */
+#line 1460 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 32:
-#line 147 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 144 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {appendnode((yyvsp[-4].str),(yyvsp[-2].str),(yyvsp[0].str));}
-#line 1469 "grammar.c" /* yacc.c:1646  */
+#line 1466 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 33:
-#line 150 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 147 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {attrstmt((yyvsp[-2].i),(yyvsp[-1].str));}
-#line 1475 "grammar.c" /* yacc.c:1646  */
+#line 1472 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 34:
-#line 151 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 148 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {attrstmt(T_graph,NULL);}
-#line 1481 "grammar.c" /* yacc.c:1646  */
+#line 1478 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 35:
-#line 154 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 151 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.i) = T_graph;}
-#line 1487 "grammar.c" /* yacc.c:1646  */
+#line 1484 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 36:
-#line 155 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 152 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.i) = T_node;}
-#line 1493 "grammar.c" /* yacc.c:1646  */
+#line 1490 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 37:
-#line 156 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 153 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.i) = T_edge;}
-#line 1499 "grammar.c" /* yacc.c:1646  */
+#line 1496 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 38:
-#line 159 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 156 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.str) = (yyvsp[-1].str);}
-#line 1505 "grammar.c" /* yacc.c:1646  */
+#line 1502 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 39:
-#line 160 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 157 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.str) = NULL; }
-#line 1511 "grammar.c" /* yacc.c:1646  */
+#line 1508 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 48:
-#line 175 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 172 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {appendattr((yyvsp[-2].str),(yyvsp[0].str));}
-#line 1517 "grammar.c" /* yacc.c:1646  */
+#line 1514 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 49:
-#line 178 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 175 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {appendattr((yyvsp[0].str),NULL);}
-#line 1523 "grammar.c" /* yacc.c:1646  */
+#line 1520 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 51:
-#line 184 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 181 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {opensubg((yyvsp[0].str));}
-#line 1529 "grammar.c" /* yacc.c:1646  */
+#line 1526 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 52:
-#line 184 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 181 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {closesubg();}
-#line 1535 "grammar.c" /* yacc.c:1646  */
+#line 1532 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 53:
-#line 187 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 184 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.str)=(yyvsp[0].str);}
-#line 1541 "grammar.c" /* yacc.c:1646  */
+#line 1538 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 54:
-#line 188 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 185 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.str)=NULL;}
-#line 1547 "grammar.c" /* yacc.c:1646  */
+#line 1544 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 55:
-#line 189 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 186 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.str)=NULL;}
-#line 1553 "grammar.c" /* yacc.c:1646  */
+#line 1550 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 59:
-#line 194 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 191 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.str) = (yyvsp[0].str);}
-#line 1559 "grammar.c" /* yacc.c:1646  */
+#line 1556 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 60:
-#line 195 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 192 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.str) = (yyvsp[0].str);}
-#line 1565 "grammar.c" /* yacc.c:1646  */
+#line 1562 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 61:
-#line 198 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 195 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.str) = (yyvsp[0].str);}
-#line 1571 "grammar.c" /* yacc.c:1646  */
+#line 1568 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 62:
-#line 199 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 196 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.str) = concat((yyvsp[-2].str),(yyvsp[0].str));}
-#line 1577 "grammar.c" /* yacc.c:1646  */
+#line 1574 "grammar.c" /* yacc.c:1646  */
     break;
 
 
-#line 1581 "grammar.c" /* yacc.c:1646  */
+#line 1578 "grammar.c" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1805,7 +1802,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 201 "../../lib/cgraph/grammar.y" /* yacc.c:1906  */
+#line 198 "../../lib/cgraph/grammar.y" /* yacc.c:1906  */
 
 
 static item *newitem(int tag, void *p0, char *p1)
@@ -1889,7 +1886,7 @@ static void bindattrs(int kind)
 	for (aptr = S->attrlist.first; aptr; aptr = aptr->next) {
 		assert(aptr->tag == T_atom);	/* signifies unbound attr */
 		name = aptr->u.name;
-		if ((kind == AGEDGE) && streq(name,Key)) continue;
+		if (kind == AGEDGE && streq(name,Key)) continue;
 		if ((aptr->u.asym = agattr(S->g,kind,name,NULL)) == NULL)
 			aptr->u.asym = agattr(S->g,kind,name,"");
 		aptr->tag = T_attr;				/* signifies bound attr */
@@ -1909,8 +1906,7 @@ static void applyattrs(void *obj)
 			}
 		}
 		else {
-			/* assert(AGTYPE(obj) == AGEDGE);  surprising this fails */
-			assert((AGTYPE(obj) == AGINEDGE) || (AGTYPE(obj) == AGOUTEDGE));
+			assert(AGTYPE(obj) == AGINEDGE || AGTYPE(obj) == AGOUTEDGE);
 			assert(aptr->tag == T_atom);
 			assert(streq(aptr->u.name,Key));
 		}
@@ -1942,6 +1938,7 @@ static void attrstmt(int tkind, char *macroname)
 		case T_graph: kind = AGRAPH; break;
 		case T_node: kind = AGNODE; break;
 		case T_edge: kind = AGEDGE; break;
+		default: UNREACHABLE();
 	}
 	bindattrs(kind);	/* set up defaults for new attributes */
 	for (aptr = S->attrlist.first; aptr; aptr = aptr->next) {
