@@ -8,8 +8,7 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#ifndef GV_CONST_H
-#define GV_CONST_H
+#pragma once
 
 #define SMALLBUF	128
 #define LPAREN		'('
@@ -263,13 +262,13 @@
  */
 
 /* edge types */
-#define ET_NONE 	(0 << 1)
-#define ET_LINE 	(1 << 1)
-#define ET_CURVED 	(2 << 1)
-#define ET_PLINE 	(3 << 1)
-#define ET_ORTHO 	(4 << 1)
-#define ET_SPLINE 	(5 << 1)
-#define ET_COMPOUND 	(6 << 1)
+#define EDGETYPE_NONE       (0 << 1)
+#define EDGETYPE_LINE       (1 << 1)
+#define EDGETYPE_CURVED     (2 << 1)
+#define EDGETYPE_PLINE      (3 << 1)
+#define EDGETYPE_ORTHO      (4 << 1)
+#define EDGETYPE_SPLINE     (5 << 1)
+#define EDGETYPE_COMPOUND   (6 << 1)
 
 /* New ranking is used */
 #define NEW_RANK    	(1 << 4)
@@ -286,5 +285,3 @@
 #define FONTSIZE_MUCH_TOO_SMALL 0.15
 /* fontsize at which text is rendered by a simple line */
 #define FONTSIZE_TOO_SMALL 1.5
-
-#endif
