@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,18 +5,17 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#pragma once
+
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-#ifndef TLAYOUT_H
-#define TLAYOUT_H
-
-#include "fdp.h"
-#include "xlayout.h"
+#include <fdpgen/fdp.h>
+#include <fdpgen/xlayout.h>
 
 typedef enum {
   seed_unset, seed_val, seed_time, seed_regular
@@ -28,8 +24,6 @@ typedef enum {
     extern void fdp_initParams(graph_t *);
     extern void fdp_tLayout(graph_t *, xparams *);
 
-#endif
-
 #ifdef __cplusplus
 }
 #endif
