@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,15 +5,16 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#include "LinkedList.h"
-#include "PriorityQueue.h"
-#include "memory.h"
-#include "logic.h"
-#include "assert.h"
-#include "arith.h"
+#include <sparse/LinkedList.h>
+#include <sfdpgen/PriorityQueue.h>
+#include <common/memory.h>
+#include <common/logic.h>
+#include <assert.h>
+#include <common/arith.h>
+#include <stddef.h>
 
 PriorityQueue PriorityQueue_new(int n, int ngain){
   PriorityQueue q;
@@ -47,9 +45,7 @@ void PriorityQueue_delete(PriorityQueue q){
       free(q->buckets);
     }
 
-    if (q->where){
-      free(q->where);
-    }
+    free(q->where);
 
     free(q->gain);
     free(q);
