@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #include "config.h"
@@ -16,15 +13,15 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "gvplugin_loadimage.h"
-#include "gvio.h"
+#include <gvc/gvplugin_loadimage.h>
+#include <gvc/gvio.h>
 
 #ifdef HAVE_WEBP
 #ifdef HAVE_PANGOCAIRO
 #include <cairo.h>
 #include <webp/decode.h>
 
-#ifdef WIN32 //*dependencies
+#ifdef _WIN32 //*dependencies
     #pragma comment( lib, "gvc.lib" )
     #pragma comment( lib, "glib-2.0.lib" )
     #pragma comment( lib, "pango-1.0.lib" )
@@ -46,7 +43,7 @@ typedef enum {
 
 static void webp_freeimage(usershape_t *us)
 {
-    cairo_surface_destroy((cairo_surface_t*)(us->data));
+    cairo_surface_destroy(us->data);
 }
 
 static cairo_surface_t* webp_really_loadimage(const char *in_file, FILE* const in)
@@ -77,13 +74,13 @@ static cairo_surface_t* webp_really_loadimage(const char *in_file, FILE* const i
         return NULL;
     }
 
-    status = WebPGetFeatures((const uint8_t*)data, data_size, bitstream);
+    status = WebPGetFeatures(data, data_size, bitstream);
     if (status != VP8_STATUS_OK) {
 	goto end;
     }
 
     output_buffer->colorspace = MODE_RGBA;
-    status = WebPDecode((const uint8_t*)data, data_size, &config);
+    status = WebPDecode(data, data_size, &config);
 
     /* FIXME - this is ugly */
     if (! bitstream->has_alpha) {
@@ -131,7 +128,7 @@ static cairo_surface_t* webp_loadimage(GVJ_t * job, usershape_t *us)
 
     if (us->data) {
         if (us->datafree == webp_freeimage)
-             surface = (cairo_surface_t*)(us->data); /* use cached data */
+             surface = us->data; /* use cached data */
         else {
              us->datafree(us);        /* free incompatible cache data */
              us->datafree = NULL;
@@ -150,7 +147,7 @@ static cairo_surface_t* webp_loadimage(GVJ_t * job, usershape_t *us)
                 surface = NULL;
         }
         if (surface) {
-            us->data = (void*)surface;
+            us->data = surface;
             us->datafree = webp_freeimage;
         }
 	gvusershape_file_release(us);
